==> tekton-model-triggers-v1alpha1-6.5.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterInterceptorSpecFluentImpl<A extends ClusterInterceptorSpecFluent<A>> extends BaseFluent<A> implements ClusterInterceptorSpecFluent<A>{
  public ClusterInterceptorSpecFluentImpl() {
  }
  public ClusterInterceptorSpecFluentImpl(ClusterInterceptorSpec instance) {
    this.withClientConfig(instance.getClientConfig()); 
  }
  private ClientConfigBuilder clientConfig;
  
  /**
   * This method has been deprecated, please use method buildClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientConfig getClientConfig() {
    return this.clientConfig!=null ?this.clientConfig.build():null;
  }
  public ClientConfig buildClientConfig() {
    return this.clientConfig!=null ?this.clientConfig.build():null;
  }
  public A withClientConfig(ClientConfig clientConfig) {
    _visitables.get("clientConfig").remove(this.clientConfig);
    if (clientConfig!=null){ this.clientConfig= new ClientConfigBuilder(clientConfig); _visitables.get("clientConfig").add(this.clientConfig);} else { this.clientConfig = null; _visitables.get("clientConfig").remove(this.clientConfig); } return (A) this;
  }
  public Boolean hasClientConfig() {
    return this.clientConfig != null;
  }
  public ClusterInterceptorSpecFluent.ClientConfigNested<A> withNewClientConfig() {
    return new ClusterInterceptorSpecFluentImpl.ClientConfigNestedImpl();
  }
  public ClusterInterceptorSpecFluent.ClientConfigNested<A> withNewClientConfigLike(ClientConfig item) {
    return new ClusterInterceptorSpecFluentImpl.ClientConfigNestedImpl(item);
  }
  public ClusterInterceptorSpecFluent.ClientConfigNested<A> editClientConfig() {
    return withNewClientConfigLike(getClientConfig());
  }
  public ClusterInterceptorSpecFluent.ClientConfigNested<A> editOrNewClientConfig() {
    return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): new ClientConfigBuilder().build());
  }
  public ClusterInterceptorSpecFluent.ClientConfigNested<A> editOrNewClientConfigLike(ClientConfig item) {
    return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterInterceptorSpecFluentImpl that = (ClusterInterceptorSpecFluentImpl) o;
    if (clientConfig != null ? !clientConfig.equals(that.clientConfig) :that.clientConfig != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientConfig,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientConfig != null) { sb.append("clientConfig:"); sb.append(clientConfig); }
    sb.append("}");
    return sb.toString();
  }
  class ClientConfigNestedImpl<N> extends ClientConfigFluentImpl<ClusterInterceptorSpecFluent.ClientConfigNested<N>> implements ClusterInterceptorSpecFluent.ClientConfigNested<N>,Nested<N>{
    ClientConfigNestedImpl(ClientConfig item) {
      this.builder = new ClientConfigBuilder(this, item);
    }
    ClientConfigNestedImpl() {
      this.builder = new ClientConfigBuilder(this);
    }
    ClientConfigBuilder builder;
    public N and() {
      return (N) ClusterInterceptorSpecFluentImpl.this.withClientConfig(builder.build());
    }
    public N endClientConfig() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorSpecFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterInterceptorSpecFluentImpl<A extends ClusterInterceptorSpecFluent<A>> extends BaseFluent<A> implements ClusterInterceptorSpecFluent<A>{
  public ClusterInterceptorSpecFluentImpl() {
  }
  public ClusterInterceptorSpecFluentImpl(ClusterInterceptorSpec instance) {
    if (instance != null) {
      this.withClientConfig(instance.getClientConfig());
    }
  }
  private ClientConfigBuilder clientConfig;
  
  /**
   * This method has been deprecated, please use method buildClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientConfig getClientConfig() {
    return this.clientConfig!=null ?this.clientConfig.build():null;
  }
  public ClientConfig buildClientConfig() {
    return this.clientConfig!=null ?this.clientConfig.build():null;
  }
  public A withClientConfig(ClientConfig clientConfig) {
    _visitables.get("clientConfig").remove(this.clientConfig);
    if (clientConfig!=null){ this.clientConfig= new ClientConfigBuilder(clientConfig); _visitables.get("clientConfig").add(this.clientConfig);} else { this.clientConfig = null; _visitables.get("clientConfig").remove(this.clientConfig); } return (A) this;
  }
  public Boolean hasClientConfig() {
    return this.clientConfig != null;
  }
  public ClusterInterceptorSpecFluentImpl.ClientConfigNested<A> withNewClientConfig() {
    return new ClusterInterceptorSpecFluentImpl.ClientConfigNestedImpl();
  }
  public ClusterInterceptorSpecFluentImpl.ClientConfigNested<A> withNewClientConfigLike(ClientConfig item) {
    return new ClusterInterceptorSpecFluentImpl.ClientConfigNestedImpl(item);
  }
  public ClusterInterceptorSpecFluentImpl.ClientConfigNested<A> editClientConfig() {
    return withNewClientConfigLike(getClientConfig());
  }
  public ClusterInterceptorSpecFluentImpl.ClientConfigNested<A> editOrNewClientConfig() {
    return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): new ClientConfigBuilder().build());
  }
  public ClusterInterceptorSpecFluentImpl.ClientConfigNested<A> editOrNewClientConfigLike(ClientConfig item) {
    return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterInterceptorSpecFluentImpl that = (ClusterInterceptorSpecFluentImpl) o;
    if (!java.util.Objects.equals(clientConfig, that.clientConfig)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientConfig,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientConfig != null) { sb.append("clientConfig:"); sb.append(clientConfig); }
    sb.append("}");
    return sb.toString();
  }
  class ClientConfigNestedImpl<N> extends ClientConfigFluentImpl<ClusterInterceptorSpecFluentImpl.ClientConfigNested<N>> implements ClusterInterceptorSpecFluentImpl.ClientConfigNested<N>,Nested<N>{
    ClientConfigNestedImpl(ClientConfig item) {
      this.builder = new ClientConfigBuilder(this, item);
    }
    ClientConfigNestedImpl() {
      this.builder = new ClientConfigBuilder(this);
    }
    ClientConfigBuilder builder;
    public N and() {
      return (N) ClusterInterceptorSpecFluentImpl.this.withClientConfig(builder.build());
    }
    public N endClientConfig() {
      return and();
    }
    
  }
  
}
